[Cmake-commits] CMake branch, next, updated. v2.8.10.2-2697-g5a717d6

Eric Noulard eric.noulard at gmail.com
Mon Apr 1 10:10:18 EDT 2013


This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
       via  5a717d67a40e89961d846dd762b9787c3c6374b7 (commit)
       via  2ef908f91147928fb3b37a8439784341eb82ea6a (commit)
      from  b01cd269cc17018e091b418d22c1e99c797bcd53 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=5a717d67a40e89961d846dd762b9787c3c6374b7
commit 5a717d67a40e89961d846dd762b9787c3c6374b7
Merge: b01cd26 2ef908f
Author:     Eric Noulard <eric.noulard at gmail.com>
AuthorDate: Mon Apr 1 10:10:17 2013 -0400
Commit:     CMake Topic Stage <kwrobot at kitware.com>
CommitDate: Mon Apr 1 10:10:17 2013 -0400

    Merge topic 'CPackRPM-componentizedUserSpecFile' into next
    
    2ef908f Add support for componentized USER spec file


http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=2ef908f91147928fb3b37a8439784341eb82ea6a
commit 2ef908f91147928fb3b37a8439784341eb82ea6a
Author:     Eric NOULARD <eric.noulard at gmail.com>
AuthorDate: Mon Apr 1 16:06:22 2013 +0200
Commit:     Eric NOULARD <eric.noulard at gmail.com>
CommitDate: Mon Apr 1 16:06:22 2013 +0200

    Add support for componentized USER spec file
    
    CPACK_RPM_USER_BINARY_SPECFILE can now be specified on a per-component
    basis using CPACK_RPM_<componentName>_USER_BINARY_SPECFILE.
    
    Inspired-By: Theodore Papadopoulo with its patch proposal.

diff --git a/Modules/CPackRPM.cmake b/Modules/CPackRPM.cmake
index fa79e1b..024822e 100644
--- a/Modules/CPackRPM.cmake
+++ b/Modules/CPackRPM.cmake
@@ -163,6 +163,8 @@
 #     May be set by the user in order to specify a USER binary spec file
 #     to be used by CPackRPM instead of generating the file.
 #     The specified file will be processed by configure_file( @ONLY).
+#     One can provide a component specific file by setting
+#     CPACK_RPM_<componentName>_USER_BINARY_SPECFILE.
 ##end
 ##variable
 #  CPACK_RPM_GENERATE_USER_BINARY_SPECFILE_TEMPLATE - Spec file template.
@@ -832,11 +834,18 @@ if(CPACK_RPM_PACKAGE_DEBUG)
    message("CPackRPM:Debug: CPACK_TEMPORARY_PACKAGE_FILE_NAME = ${CPACK_TEMPORARY_PACKAGE_FILE_NAME}")
 endif()
 
-# USER generated spec file handling.
-# We should generate a spec file template:
+#
+# USER generated/provided spec file handling.
+#
+
+# We can have a component specific spec file.
+if(CPACK_RPM_PACKAGE_COMPONENT AND CPACK_RPM_${CPACK_RPM_PACKAGE_COMPONENT}_USER_BINARY_SPECFILE)
+  set(CPACK_RPM_USER_BINARY_SPECFILE ${CPACK_RPM_${CPACK_RPM_PACKAGE_COMPONENT}_USER_BINARY_SPECFILE})
+endif()
+
+# We should generate a USER spec file template:
 #  - either because the user asked for it : CPACK_RPM_GENERATE_USER_BINARY_SPECFILE_TEMPLATE
 #  - or the user did not provide one : NOT CPACK_RPM_USER_BINARY_SPECFILE
-#
 if(CPACK_RPM_GENERATE_USER_BINARY_SPECFILE_TEMPLATE OR NOT CPACK_RPM_USER_BINARY_SPECFILE)
    file(WRITE ${CPACK_RPM_BINARY_SPECFILE}.in
       "# -*- rpm-spec -*-
@@ -902,9 +911,9 @@ mv \"\@CPACK_TOPLEVEL_DIRECTORY\@/tmpBBroot\" $RPM_BUILD_ROOT
 
 %files
 %defattr(-,root,root,-)
-${CPACK_RPM_INSTALL_FILES}
-${CPACK_RPM_ABSOLUTE_INSTALL_FILES}
-${CPACK_RPM_USER_INSTALL_FILES}
+\@CPACK_RPM_INSTALL_FILES\@
+\@CPACK_RPM_ABSOLUTE_INSTALL_FILES\@
+\@CPACK_RPM_USER_INSTALL_FILES\@
 
 %changelog
 \@CPACK_RPM_SPEC_CHANGELOG\@

-----------------------------------------------------------------------

Summary of changes:
 Modules/CPackRPM.cmake |   21 +++++++++++++++------
 1 files changed, 15 insertions(+), 6 deletions(-)


hooks/post-receive
-- 
CMake


More information about the Cmake-commits mailing list